[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/esspolarization.svg)](https://pypi.python.org/pypi/esspolarization)
[![Anaconda-Server Badge](https://anaconda.org/scipp/esspolarization/badges/version.svg)](https://anaconda.org/scipp/esspolarization)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

# ESSpolarization

## About

Polarization data reduction for the European Spallation Source

## Installation

```sh
python -m pip install esspolarization
```
